@@ -20,6 +20,7 @@ from indico_install.utils import (
 TRACKER_CONFIGMAP = "cluster-manager"
 TRACKER_CONFIGMAP_BACKUP = "cluster-manager-backup"
 LOCK_TIMEOUT = 60  # seconds to wait for configmap lock
+UPDRAFT_BUCKET = "gs://indico-templates"
 
 
 """
@@ -57,6 +58,21 @@ def get_services_from_tag(updraft_tag):
     return results
 
 
+def _list_versions(grep):
+    grep = f" | grep {grep}" if grep else ""
+    out = run_cmd(f"gsutil ls -d {UPDRAFT_BUCKET}{grep}", silent=True).splitlines()
+    return [i[len(UPDRAFT_BUCKET):].replace('/', '') for i in out]
+
+
+def _list_versions_ordered(grep):
+    out = run_cmd(f"gsutil ls -l {UPDRAFT_BUCKET}/*{grep}*/services.yaml", silent=True).splitlines()[:-1]
+    return [
+        f"{i[0]} " + i[1][len(UPDRAFT_BUCKET):-len("services.yaml")].replace('/', '') for i in
+        sorted([i.split()[1:] for i in out], key=lambda x: x[0], reverse=True)
+    ]
+
+
+
 class ClusterManager(object):
     """
     TODO: make this hold state of the actual input file
@@ -135,6 +151,12 @@ class ClusterManager(object):
             updates["frontend"] = {"hash": self.cluster_config["frontend"].pop("hash")}
         return updates
 
+    @classmethod
+    def get_updraft_versions(cls, regex, number, ordered):
+        regex = string_to_tag(regex)
+        res_list = _list_versions_ordered(regex) if ordered else _list_versions(regex)
+        return res_list[:number] if number else res_list
+
     def load_from_cluster(self, backup=False):
         """
         Use the version configmap on the cluster to populate this Tracker instance
